/***************************************************************************
 *   Copyright (C) 2003 by Danny Kurniawan                                 *
 *   danny@it.petra.ac.id                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>

#include "clonecd.h"

int main(int argc, char *argv[])
{
	ccd_sector src_sect;
	int bytes_read, bytes_written, sect_num = 0;

	FILE *src_file;
	FILE *dst_file;

	if ((!argv[1]) || (!argv[2]))
	{
		printf("Usage: ccd2iso <.img filename> <.iso filename>\n");
		return 1;
	}

	src_file = fopen(argv[1], "r");
	dst_file = fopen(argv[2], "w");

	while(!feof(src_file))
	{
		bytes_read = fread(&src_sect, 1, sizeof(ccd_sector), src_file);

		if (bytes_read != 0)
		{
			if (bytes_read < sizeof(ccd_sector))
			{
				printf("Error at sector %d.\n", sect_num);
				printf("The sector does not contain complete data. Sector size must be %d, while actual data read is %d\n",
					sizeof(ccd_sector), bytes_read);
				return 1;
			}

			switch (src_sect.sectheader.header.mode)
			{
				case 1:  // Mode 1 Data Sector
					bytes_written = fwrite(&(src_sect.content.mode1.data), 1, DATA_SIZE, dst_file);
					break;
				case 2:  // Mode 2 Data Sector
					bytes_written = fwrite(&(src_sect.content.mode2.data), 1, DATA_SIZE, dst_file);
					break;
				default:
					printf("Unrecognized sector mode (%x) at sector %d!\n", src_sect.sectheader.header.mode, sect_num);
					return 1;
			}
			
			if (bytes_written < DATA_SIZE)
			{
				printf("Error writing to file.\n");
				return 1;
			}

			sect_num++;
			printf("%d sector written\r", sect_num);
		}
	}
	fclose(src_file);
	fclose(dst_file);

	printf("\nDone.\n");

	return 0;
}
